@@ -47,8 +47,6 @@ Python bindings for the v4l2 userspace api
 # see linux/videodev2.h
 
 import ctypes
-from os import errno
-from fcntl import ioctl
 
 
 _IOC_NRBITS = 8
@@ -840,6 +838,7 @@ class v4l2_ext_control(ctypes.Structure):
     ]
 
     _anonymous_ = ('_u',)
+    _pack_ = True
 
 
 class v4l2_ext_controls(ctypes.Structure):
@@ -1510,6 +1509,8 @@ class v4l2_register(ctypes.Structure):
         ('val', ctypes.c_uint64),
     ]
 
+    _pack_ = True
+
 
 class v4l2_chip_ident(ctypes.Structure):
     _fields_ = [
@@ -1519,6 +1520,8 @@ class v4l2_chip_ident(ctypes.Structure):
         ('version', ctypes.c_uint32),
     ]
 
+    _pack_ = True
+    
 
 #
 # ioctl codes for video devices
